{% extends "account/base_entrance.html" %}{% load i18n allauth %}

<!---->
{% block head_title %}{% trans "Sign Up Closed" %}{% endblock %}

<!---->
{% block content %}
<div class="container-prose">
  <h1>{% trans "Sign Up Closed" %}</h1>

  <p>{% trans "We are sorry, but the sign up is currently closed." %}</p>
</div>
{% endblock %}
