{% extends "account/base_entrance.html" %}{% load i18n allauth account %}

<!---->
{% block head_title %}{% trans "Password Reset" %}{% endblock %}

<!---->
{% block content %}
<div class="container-prose">
  <h1>{% trans "Password Reset" %}</h1>

  {% if user.is_authenticated %}
  <!---->
  {% include 'account/snippets/already_logged_in.html' %}
  <!---->
  {% endif %}

  <!---->
  <p>
    {% blocktrans trimmed %}Forgotten your password? Enter your email address
    below, and we'll send you an email allowing you to reset it.{% endblocktrans %}
  </p>

  <form
    action="{% url 'account_reset_password' %}"
    method="post"
    class="grid gap-4"
  >
    {% csrf_token %}{{ redirect_field }}

    <!---->
    {% include 'allauth/components/form.html' %}

    <button
      type="submit"
      class="btn btn-sm btn-primary lg:btn-md 2xl:btn-lg"
    >
      {% trans 'Reset My Password' %}
    </button>
  </form>

  <p>
    {% blocktrans trimmed %}Please contact us if you have any trouble resetting
    your password.{% endblocktrans %}
  </p>
</div>
{% endblock %}
