{% extends "account/base_confirm_code.html" %}{% load i18n allauth account %}

<!---->
{% block head_title %}{% trans "Password Reset" %}{% endblock head_title %}

<!---->
{% block title %}{% trans "Enter Password Reset Code" %}{% endblock %}

<!---->
{% block recipient %}<a href="mailto:{{ email }}">{{ email }}</a>{% endblock %}

<!---->
{% block action_url %}{% url 'account_confirm_password_reset_code' %}{% endblock %}
