{% extends "account/base_manage_password.html" %}{% load i18n allauth %}

<!---->
{% block head_title %}{% trans "Set Password" %}{% endblock %}

<!---->
{% block content %}
<div class="container-prose">
  <h1>{% trans "Set Password" %}</h1>

  <form
    action="{% url 'account_set_password' %}"
    method="post"
    class="grid gap-4"
  >
    {% csrf_token %}{{ redirect_field }}

    <!---->
    {% include 'allauth/components/form.html' %}

    <button
      type="submit"
      name="action"
      class="btn btn-sm btn-primary lg:btn-md 2xl:btn-lg"
    >
      <i data-lucide="save" class="size-4 lg:size-6"></i>
      {% trans 'Set Password' %}
    </button>
  </form>
</div>
{% endblock %}
