{% extends "account/base_entrance.html" %}{% load i18n allauth %}

<!---->
{% block head_title %}{% trans "Verify Your Email Address" %}{% endblock %}

<!---->
{% block content %}
<div class="container-prose">
  <h1>{% trans "Verify Your Email Address" %}</h1>

  <p>
    {% blocktrans trimmed %}We have sent an email to you for verification.
    Follow the link provided to finalize the signup process. If you do not see
    the verification email in your main inbox, check your spam folder. Please
    contact us if you do not receive the verification email within a few
    minutes.{% endblocktrans %}
  </p>
</div>
{% endblock %}
