{% extends 'allauth/layouts/manage.html' %}{% load i18n account %}

<!---->
{% block head_title %}{% trans 'Account' %}{% endblock %}

<!---->
{% block content %}
<div class="container-prose">
  {% user_display request.user as user_display %}

  <h1>{% trans 'Profile' %}</h1>

  <p>
    {% blocktrans trimmed %}Welcome <strong>{{ user_display }}</strong>. Here
    you can manage your account and settings.{% endblocktrans %}
  </p>
</div>
{% endblock %}
