{% extends "allauth/layouts/entrance.html" %}{% load i18n allauth %}

<!---->
{% block head_title %}{% trans "Authorize" %}{% endblock %}

<!---->
{% block content %}
<div class="container-prose">
  <h1>{% trans "Enter Device Code" %}</h1>

  <p>
    {% blocktrans %}Enter the code displayed on your device.{% endblocktrans %}
  </p>

  <form action="{{ authorization_url }}" method="get" class="grid gap-4">
    {% include 'allauth/components/form.html' %}

    <button type="submit" class="btn btn-sm btn-primary lg:btn-md 2xl:btn-lg">
      <i data-lucide="circle-check" class="size-4 lg:size-6"></i>
      {% trans "Continue" %}
    </button>
  </form>
</div>
{% endblock %}
