{% extends "account/base_manage_password.html" %}{% load i18n allauth %}

<!---->
{% block head_title %}{% trans "Change Password" %}{% endblock %}

<!---->
{% block content %}
<div class="container-prose">
  <h1>{% trans "Change Password" %}</h1>

  {% url 'account_change_password' as action_url %}

  <form action="{{ action_url }}" method="post" class="not-prose grid gap-4">
    {% csrf_token %}{{ redirect_field }}

    <!---->
    {% include 'allauth/components/form.html' %}

    <div class="w-full grid gap-4 md:flex md:items-center">
      <button
        type="submit"
        class="grow btn btn-sm btn-primary lg:btn-md 2xl:btn-lg"
      >
        <i data-lucide="rotate-ccw-key" class="size-4 lg:size-6"></i>
        {% trans "Change Password" %}
      </button>

      <a
        href="{% url 'account_reset_password' %}"
        class="grow btn btn-sm btn-secondary lg:btn-md 2xl:btn-lg"
      >
        <i data-lucide="circle-question-mark" class="size-4 lg:size-6"></i>
        {% trans "Forgot Password?" %}
      </a>
    </div>
  </form>
</div>
{% endblock %}
