{% extends "allauth/layouts/manage.html" %}{% load i18n %}

<!---->
{% block breadcrumbs %}
<li>
  <a href="{% url 'socialaccount_connections' %}">
    <i data-lucide="handshake" class="size-4"></i>
    {% trans 'Connections' %}
  </a>
</li>
{% endblock %}
