@import url('https://fonts.googleapis.com/css2?family=Noto+Kufi+Arabic:wght@100..900&family=Noto+Sans:ital,wght@0,100..900;1,100..900&family=Noto+Serif:ital,wght@0,100..900;1,100..900&display=swap');

@import "tailwindcss";
@plugin "@tailwindcss/typography";

@plugin "daisyui" {
  themes: all;
}

@theme {
  --font-sans:
    'Noto Sans', ui-sans-serif, system-ui, sans-serif, 'Apple Color Emoji',
    'Segoe UI Emoji', 'Segoe UI Symbol', 'Noto Color Emoji';
  --font-serif:
    'Noto Serif', ui-sans-serif, system-ui, sans-serif, 'Apple Color Emoji',
    'Segoe UI Emoji', 'Segoe UI Symbol', 'Noto Color Emoji';
  --font-kufi:
    'Noto Kufi Arabic', ui-sans-serif, system-ui, sans-serif,
    'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', 'Noto Color Emoji';
}

@layer base {
  .container-prose {
    @apply w-full mx-auto prose prose-sm lg:prose-base xl:prose-lg 2xl:prose-xl prose-a:link prose-a:no-underline prose-a:link-hover prose-a:link-info prose-a:font-semibold;
  }
}