{% extends "allauth/layouts/manage.html" %}{% load i18n %}

<!---->
{% block breadcrumbs %}
<li>
  <a href="{% url 'mfa_index' %}">
    <i data-lucide="fingerprint" class="size-4"></i>
    {% trans 'Two-Factor Authentication' %}
  </a>
</li>
{% endblock %}
