{% extends "allauth/layouts/entrance.html" %}{% load i18n allauth %}

<!---->
{% block head_title %}{% trans "Account Inactive" %}{% endblock %}

<!---->
{% block content %}
<div class="container-prose">
  <h1>{% trans "Account Inactive" %}</h1>

  <p>{% trans "This account is inactive." %}</p>
</div>
{% endblock %}
