{% extends "account/base_manage.html" %}{% load i18n %}

<!---->
{% block breadcrumbs %}
<li>
  <a href="{% url 'account_change_password' %}">
    <i data-lucide="key" class="size-4"></i>
    {% trans 'Password' %}
  </a>
</li>
{% endblock %}
