{% extends "socialaccount/base_entrance.html" %}{% load i18n allauth %}

<!---->
{% block head_title %}{% trans "Login Cancelled" %}{% endblock %}

<!---->
{% block content %}
<div class="container-prose">
  <h1>{% trans "Login Cancelled" %}</h1>

  {% url 'account_login' as login_url %}
  <p>
    {% blocktrans trimmed %}You decided to cancel logging in to our site using
    one of your existing accounts. If this was a mistake, please proceed to
    <a href="{{login_url}}">sign in</a>.{% endblocktrans %}
  </p>
</div>
{% endblock %}
