{% extends "allauth/layouts/entrance.html" %}{% load i18n allauth %}

<!---->
{% block head_title %}{% trans "Error" %}{% endblock %}

<!---->
{% block content %}
<div class="container-prose">
  <h1>{% trans "Error" %}</h1>

  <p>{{ error.description }}</p>
</div>
{% endblock %}
