"""AppConf for allauth_xui"""

from django.apps import AppConfig


class AllAuthUIConfig(AppConfig):
    """App configuration for allauth_xui"""

    name = "allauth_xui"
    default_auto_field = "django.db.models.BigAutoField"
