{% extends "socialaccount/base_entrance.html" %}{% load i18n allauth %}

<!---->
{% block head_title %}{% trans "Sign In" %}{% endblock %}

<!---->
{% block content %}
<div class="container-prose">
  {% if process == "connect" %}
  <h1>
    {% blocktrans with provider.name as provider trimmed %}Connect {{ provider }}{% endblocktrans %}
  </h1>
  <p>
    {% blocktrans with provider.name as provider trimmed %}You are about to
    connect a new third-party account from {{ provider }}.{% endblocktrans %}
  </p>
  {% else %}
  <h1>
    {% blocktrans with provider.name as provider trimmed %}Sign In Via {{ provider }}{% endblocktrans %}
  </h1>
  <p>
    {% blocktrans with provider.name as provider trimmed %}You are about to sign
    in using a third-party account from {{ provider }}.{% endblocktrans %}
  </p>
  {% endif %}

  <form method="post" class="grid gap-4">
    {% csrf_token %}

    <!---->
    {% include 'allauth/components/form.html' %}

    <button type="submit" class="btn btn-sm btn-primary lg:btn-md 2xl:btn-lg">
      <i data-lucide="circle-check" class="size-4 lg:size-6"></i>
      {% trans 'Continue' %}
    </button>
  </form>
</div>
{% endblock %}
