{% extends "account/base_manage.html" %}{% load i18n %}

<!---->
{% block breadcrumbs %}
<li>
  <a href="#">
    <i data-lucide="phone" class="size-4"></i>
    {% trans 'Phone' %}
  </a>
</li>
{% endblock %}
