{% extends "account/base_entrance.html" %}{% load i18n allauth account %}

<!---->
{% block head_title %}{% trans "Password Reset" %}{% endblock %}

<!---->
{% block content %}
<div class="container-prose">
  <h1>{% trans "Password Reset" %}</h1>

  {% if user.is_authenticated %}
  <!---->
  {% include 'account/snippets/already_logged_in.html' %}
  <!---->
  {% endif %}

  <p>
    {% blocktrans trimmed %}We have sent you an email. If you have not received
    it please check your spam folder. Otherwise contact us if you do not receive
    it in a few minutes.{% endblocktrans %}
  </p>
</div>
{% endblock %}
