{% extends "account/base_entrance.html" %}{% load i18n allauth %}

<!---->
{% block head_title %}{% trans "Change Password" %}{% endblock %}

<!---->
{% block content %}
<div class="container-prose">
  <h1>{% trans "Change Password" %}</h1>

  <p>{% trans 'Your password is now changed.' %}</p>
</div>
{% endblock %}
